@@ -48,7 +48,7 @@ int main(void)
 {
     char *test_db_dir;
 #ifdef _WIN32
-    test_db_dir = "./t/maxmind-db/bad-data";
+    test_db_dir = "../t/maxmind-db/bad-data";
 #else
     char cwd[500];
     char *UNUSED(tmp) = getcwd(cwd, 500);
